; $Id: dcs_choose_det_eff.pro,v 1.11 2002/09/24 15:30:18 john Exp $
; Written by J.R.D. Copley.
;************************************************************************************************
pro dcs_choose_det_eff,dcs_base,det_eff_qty,det_eff_err,ichoice,message_str,nhedet=nhedet,$
	vansumfile=vansumfile,skipdefaultchoices=skipdefaultchoices,$
	logentry=logentry
;************************************************************************************************
;
compile_opt strictarr
;
; ichoice=0 if detector efficiencies are unity.
; ichoice=1 if detector efficiencies are computed.
; ichoice=2 if detector efficiencies are computed and saved.
; ichoice=3 if detector efficiencies are restored.
;
det_eff_qty=fltarr(nhedet)+1
det_eff_err=fltarr(nhedet)
;
internalchoice=ichoice
;
if (internalchoice eq 1 or internalchoice eq 2) then begin
	if (vansumfile eq "") then begin
		logentry=logentry+string(10B)+$
		"There is no vanadium file so efficiencies cannot be computed."
		result=dialog_message(["There is no vanadium file so efficiencies cannot be computed.",$
			"Detector efficiencies will be set to unity."],/error)
		internalchoice=0
	endif
endif
;
; The variable "method" controls how the detector efficiencies are calculated.
; method=0 means the total counts are computed for each detector. (NOT AVAILABLE)
; method=1 means the sum of the elastic peaks is fitted to a Gaussian.
; method=2 means elastic peaks are individually fitted to Gaussians. (NOT AVAILABLE)
if (internalchoice eq 1 or internalchoice eq 2) then $
;
; BEGIN
;	Following lines commented out (SIMPLIFICATION PROJECT)
;	dcs_multiplechoice,dcs_base,method,$
;		"Detector_efficiency_calculation_method",message_str,60,$
;		skipdefaultchoices=skipdefaultchoices
;	Following line substituted (SIMPLIFICATION PROJECT)
	method=1
; END
;
case internalchoice of
	0: logentry=logentry+string(10B)+"Detector efficiencies have been set to unity."
	1: begin
		dcs_define_det_eff,dcs_base,det_eff_qty,det_eff_err,method,nhedet=nhedet,$
			vansumfile=vansumfile,logentry=logentry
		logentry=logentry+string(10B)+"Detector efficiencies have been computed."
	end
	2: begin
		dcs_define_det_eff,dcs_base,det_eff_qty,det_eff_err,method,nhedet=nhedet,$
			vansumfile=vansumfile,logentry=logentry
		logentry=logentry+string(10B)+"Detector efficiencies have been computed."
		repeat begin
			file=!dcs_rootname+".eff"
			fullfilename=dialog_pickfile(filter="*.eff",/fix_filter,$
				path=!dcs_outp_directory,$
				file=file,get_path=file_path,$
				title="Define the detector efficiency file.")
			cancel=fullfilename eq ""
			compok=strcmp(file_path,!dcs_outp_directory,/fold_case)
			if (not cancel and not compok) then res=dialog_message("You may not change the directory.")
		endrep until (cancel or compok)
		if (not cancel) then begin
			if (strlowcase(strmid(fullfilename,3,/reverse)) ne ".eff") then $
				fullfilename=fullfilename+".eff"
			save,filename=fullfilename,det_eff_qty,det_eff_err
			logentry=logentry+string(10B)+$
				"Detector efficiencies have been saved in file "+fullfilename
		endif
	end
	3: begin
		file=!dcs_outp_directory+!dcs_rootname+".eff"
		if (not file_test(file)) then file=!dcs_default_root+".eff" $
			else file=!dcs_rootname+".eff"
		fullfilename=dialog_pickfile(filter="*.eff",/fix_filter,$
			path=!dcs_outp_directory,/must_exist,$
			file=file,get_path=file_path,$
			title="Select the detector efficiency file.")
		cancel=fullfilename eq ""
		if (not cancel) then begin
			if (strlowcase(strmid(fullfilename,3,/reverse)) ne ".eff") then $
				fullfilename=fullfilename+".eff"
			restore,filename=fullfilename
			logentry=logentry+string(10B)+$
				"Detector efficiencies have been restored from file "+fullfilename
		endif
	end
	else:
endcase
;
end