;$Id: trifenestra_psd.pro,v 1.5 2002/07/01 20:02:07 jmspark Exp $
;*******************************************************************************
;23456789 123456789 123456789 123465798 123456789 123456789 123465789 123456789
;       10        20        30        40        50        60        70        80
;*******************************************************************************


pro checkscantype,a,scan

	scantype,a[0],s

	for i=0,n_elements(a)-1 do begin

		scantype,a[i],si
		if si ne s then begin

			errarray = ['Error caught: Files with diffent scan types'	$
					,'check files']
			a = dialog_message(errarray,/error)
			scan = ''
			return

		endif

	endfor

	scan = s
	return
end

pro rasdqscans,a,x,y,z,dz,xtitle,ytitle,title

rasdfiles,a[0],d
avy,d.hw,d.q,d.asd,d.dasd,.06,y,rio,drio,yran=[min(d.q),max(d.q)]
nw 	= 	n_elements(y)
nf	=	n_elements(a)
tt	=	where(d.tde eq 'T')
if nf gt 1 then begin
	x	=	fltarr(nf)
	z 	= 	fltarr(nf,nw)
	dz	=	z
	for i=0,nf-1 do begin
		rasdfiles,a[i],d
		x[i]	=	total(d.de[*,tt[0]])/n_elements(d.de[*,tt[0]])
		avy,d.hw,d.q,d.asd,d.dasd,.06,eo,rio,drio,yran=[min(d.q),max(d.q)]
		if (min(y) eq min(eo)) and (max(y) eq max(eo)) then begin
			z[i,*]	=	rio
			dz[i,*]	=	drio
		endif else begin
			errarray = ['Error caught: Files with different E points']
			a = dialog_message(errarray,/error)
			return
		endelse
	endfor
endif else begin
	x	=	fltarr(2)
	x[0]	=	total(d.de[*,tt[0]])/n_elements(d.de[*,tt[0]])
	x[1]	=	x[0]*1.001
	z	=	fltarr(2,nw)
	z[0,*] = rio
	z[1,*] = rio
	dz	=	fltarr(2,nw)
	dz[0,*] = drio
	dz[1,*] = drio
endelse
eso	=	sort(x)
x	=	x(eso)
z	=	z(eso,*)
dz	=	dz(eso,*)
xtitle	=	d.tde[tt[0]]+' (K)'
ytitle	=	'hw (meV)'
title 	=	'I (T,hw)'
return
end

; RASDISCANS has a fundamental flaw: it is only interested in temperature dependence.
;
pro rasdiscans,a,x,y,z,dz,xtitle,ytitle,title,a4=a4

	rasdfiles,a[0],d,xtit='A4'
	a4	=	d.de[*,0]
	ivq, d.q, d.hw, d.asd, d.dasd, x, rio, drio, eran=[-.1,.1]

	nq 	= 	n_elements(x)
	nf	=	n_elements(a)	; Number of files.

	y	=	fltarr(nf)		; Records temperatures of the files.
	z 	= 	fltarr(nq,nf)
	dz	=	z

	combine_files = 0b

	for i=0,nf-1 do begin
		rasdfiles,a[i],d
		tt	= where(d.tde eq 'T' or d.tde eq 'TEMP')	; Index where temperature is located.
		y[i] = total(d.de[*,tt[0]])/n_elements(d.de[*,tt[0]])
		ivq,d.q,d.hw,d.asd,d.dasd,qo,rio,drio,eran=[-.1,.1]

		; If the range matches, store it in the matrix.
		if (min(x) eq min(qo)) and (max(x) eq max(qo)) then begin
			z[*,i]	=	rio
			dz[*,i]	=	drio
		endif else begin
			combine_files = 1b
			break
			; errarray = ['Error caught: Files with different E points']
			; a = dialog_message(errarray,/error)
			; return
		endelse
	endfor

	if combine_files eq 1b then begin

		rasdfiles, a, d

		key_q = sort( d.q[0, *] )
		key_hw = sort( d.hw[*, 0] )

		x1 = d.q[ *, key_q ]
		y1 = d.hw[ *, key_q ]
		z1 = d.asd[ *, key_q ]
		dz1 = d.dasd[ *, key_q ]

		x = x1[ key_hw, *]
		y = y1[ key_hw, *]
		z = z1[ key_hw, *]
		dz = dz1[ key_hw, * ]

		return

	endif

	eso	=	sort(y)
	y	=	y[eso]
	z	=	z[*,eso]
	dz	=	dz[*,eso]
	ytitle	=	d.tde[tt[0]]+' (K)'
	if d.tde[tt[0]] eq 'TEMP' then ytitle = 'T (K)'
	xtitle	=	'Q (A-1)'
	title 	=	'I (Q,T)'

	return
end
;*******************************************************************************
;23456789 123456789 123456789 123465798 123456789 123456789 123465789 123456789
;       10        20        30        40        50        60        70        80
;*******************************************************************************
;
;
pro trifenestra::psd_read, event, file = file

	self -> rspinsdata, event, file = file

end
;*******************************************************************************
;23456789 123456789 123456789 123465798 123456789 123456789 123465789 123456789
;       10        20        30        40        50        60        70        80
;*******************************************************************************
pro trifenestra::rspinsdata, file = a

	if n_elements( a ) eq 0 then begin

		; Pick a SPINS data file.
		a = dialog_pickfile(/read $
			, filter=['*.ng5'] $
			, dialog_parent=event.top $
			, /multiple_files )

	endif

	if a[0] eq '' then return

	; What is this? Initialize the data with a set of dummy data points?
	self -> initvar

	xtitle = 'Q (inv_A)'
	ytitle = 'hw (meV)'
	title = 'I (Q, hw)'

	checkscantype, a, scan

	if scan eq '' then return

	if scan eq 'I' then begin

		if n_elements(a) eq 1 then begin

			rasdfiles,a,d

			if n_elements(d) eq 0 then return

			if d.tde[0] eq 'A4' then begin

				angle = d.de[*,0]
				q = d.q

			endif else begin

				q = d.de(*,0)

			endelse


			Intensity = d.asd
			hw = d.hw
			error = d.dasd

		endif else begin ; n_elements(a) ne 1

			rasdiscans,a,x,y,z,dz,xtitle,ytitle,title,a4=a4

			Intensity = z
			error = dz
			q = x
			hw = y
			angle = a4

		endelse

	endif ; scan eq 'I'

	if scan eq 'Q' then begin

		rasdqscans,a,x,y,z,dz,xtitle,ytitle,title

		Intensity = z
		error = dz
		q = x
		hw = y

	endif


	self->file_ready_objects

	void = self.oDAVE -> set( Ei = self.Ei $
		, qty = intensity $
		, err = error $
		, xdata = q $
		, ydata = hw $
		, xlabel = xtitle $
		, ylabel = ytitle $
		, histlabel = title $
		)

	if n_elements( angle ) ne 0 then begin

		if not obj_valid( self.oRaw ) then self.oRaw = obj_new('oDave')

		self.isRaw = 0b
		full = self.oRaw -> set( Ei = self.Ei $
			, qty = intensity $
			, err = error $
			, xdata = angle $
			, ydata = hw $
			, xlabel = 'Angle' $
			, ylabel = ytitle $
			, histlabel = title $
			)

		self.RawButtonString = [ 'Q -> Angle', 'Angle -> Q' ]

		if full then begin
			self -> widget_control, 'rawButton', set_value = self.RawButtonString[0]
			self -> widget_control, 'rawButton', /sensitive
		endif

	endif

	self->file_copy_objects
	self -> convert_oDave2internal, self.oDave


	return

end
;*******************************************************************************
;23456789 123456789 123456789 123465798 123456789 123456789 123465789 123456789
;       10        20        30        40        50        60        70        80
;*******************************************************************************
;
pro trifenestra::psd, event
	; Do nothing.
end
;*******************************************************************************
pro trifenestra_psd
	; Do nothing.
end
;*******************************************************************************